Learn R Programming

tigerstats (version 0.3)

BinomSkew: Skewness in the Binomial Family of Distributions

Description

An app to investigate how skewness in a binomial distribtution vanishes when np is large enough. Sample size is set at n = 50, but the user can vary p with a slider.

Usage

BinomSkew()

Arguments

Value

no value. Graphical side-effects only.

Examples

Run this code
# NOT RUN {
if (require(manipulate)) BinomSkew()
# }

Run the code above in your browser using DataLab