Learn R Programming

tigerstats (version 0.3)

barchartGC: Easy Barcharts

Description

Wrapper for barchart in package lattice. Creates a barchart from raw data using formula-data syntax similar to that of xtabs, or from a table. Defaults to a "standard" barchart in which the bars are vertical and unstacked. Supports percentage barcharts.

Usage

barchartGC(x,data=parent.frame(),type="frequency",flat=FALSE,auto.key=TRUE,
                       horizontal=FALSE,stack=FALSE,...)

Arguments

x

Either a formula or an object that can be coerced to a table. If formula, it must be of the form ~var or ~var1+var2.

data

Usually a data frame that supplies the variables in x. Variables not in the data argument are searched for in the parent environment.

type

Possible values are "frequency" and "percent".

flat

If set to TRUE, will produce barchart that resembles the layout of xtabs

auto.key

Provides a simple key

horizontal

Determines orientation of the bars (overrriden by flat)

stack

Determines whether bars for tallies are stacked on eac other or placed next to one another (overrriden by flat)

...

other arguments passed to barchart: these include main, sub, and xlab, which are likely to be familiar to students from other lattice graphical functions. An error is possible if other arguments pertaining to legends are passed (hopefully anyone interested in such will have moved on to barchart).

Value

A trellis object describing the barchart.

Examples

Run this code
# NOT RUN {
#barchart of counts for one factor variable:
barchartGC(~sex,data=m111survey)

#barchart with percentages and title:
barchartGC(~sex,data=m111survey,
   type="percent",
   main="Distribution of Sex")

#barchart of counts, to study the relationship between
#two factor variables:
barchartGC(~sex+seat,data=m111survey)

#percentage barchart, two factor variables:
barchartGC(~sex+seat,data=m111survey,type="percent")

#From tabulated data:
sexseat <- xtabs(~sex+seat,data=m111survey)
barchartGC(sexseat,type="percent",main="Sex and Seating Preference")

#from tabulated data:
dieTosses <- c(one=8,two=18,three=11,four=7,five=9,six=7)
barchartGC(dieTosses,main="60 Rolls of a Die")

# a "flat" barchart, pictorial version of xtabs() 
barchartGC(~sex+seat,data=m111survey,flat=TRUE,ylab="Sex")

# a "flat" barchart, pictorial version of xtabs() 
barchartGC(~sex+seat,data=m111survey,type="percent",flat=TRUE,ylab="Sex")
# }

Run the code above in your browser using DataLab