music: Music and Reading Comprehension
Description
An experiment performed by a student at Georgetown College. Forty-four subjects were randomized into four
groups. All subjects read an article; one group read in a silent environment, while the other three groups
heard each three different genres of music. Each subject took a reading comprehension test afterward. {a factor with levels Female Male}
year {class rank of subject}
computer {a numeric vector}
type {type of music subject listened to while reading}
score {number of questions correct on reading comprehension test}format
A data frame with 44 observations on 4 variables.source
Matt Doolin, MAT 111 at Georgetown College